==> haskell-hls-fourmolu-plugin-2.1.0.0-103-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.1.0.0-K1yBP78QOeb7yY4H5Lbmbd
key:                  hls-fourmolu-plugin-2.1.0.0-K1yBP78QOeb7yY4H5Lbmbd
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  66776d911499a94c33c8ec1730843d61
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-fourmolu-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.1.0.0-K1yBP78QOeb7yY4H5Lbmbd
depends:
    base-4.18.2.1 filepath-1.4.300.1
    fourmolu-0.12.0.0-I95Am307TjY3ZhpCSsp64p ghc-9.6.6
    ghc-boot-th-9.6.6 ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1
    process-extras-0.7.4-9NzOAAGVuj3DoyZ1Rx1hnT text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-fourmolu-plugin-2.1.0.0-105-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.1.0.0-CzGK22iliQA1ERawaN54c
key:                  hls-fourmolu-plugin-2.1.0.0-CzGK22iliQA1ERawaN54c
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4662535bb67edbd0b3a8d60190c5664f
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-fourmolu-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.1.0.0-CzGK22iliQA1ERawaN54c
depends:
    base-4.18.2.1 filepath-1.4.300.1
    fourmolu-0.12.0.0-6YmwHckOPykGAShToXMyaJ ghc-9.6.6
    ghc-boot-th-9.6.6 ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    mtl-2.3.1 process-extras-0.7.4-H29dA3x3E0dFz53LKTFN5X text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
